@@ -1,5 +1,4 @@
 import json
-import re
 import threading
 import time
 
@@ -7,7 +6,7 @@ from platypush.context import get_bus
 from platypush.plugins import action
 from platypush.plugins.media import MediaPlugin, PlayerState
 from platypush.message.event.media import MediaPlayEvent, MediaPauseEvent, MediaStopEvent, \
-    MediaSeekEvent, MediaVolumeChangedEvent, NewPlayingMediaEvent
+    MediaSeekEvent, MediaVolumeChangedEvent
 
 
 # noinspection PyUnusedLocal
@@ -100,7 +99,8 @@ class MediaKodiPlugin(MediaPlugin):
         bus.post(evt_type(player=self.host, plugin='media.kodi', **evt))
 
     def _on_ws_msg(self):
-        def hndl(ws, msg):
+        def hndl(*args):
+            msg = args[1] if len(args) > 1 else args[0]
             self.logger.info("Received Kodi message: {}".format(msg))
             msg = json.loads(msg)
             method = msg.get('method')
@@ -129,12 +129,13 @@ class MediaKodiPlugin(MediaPlugin):
         return hndl
 
     def _on_ws_error(self):
-        def hndl(ws, error):
+        def hndl(*args):
+            error = args[1] if len(args) > 1 else args[0]
             self.logger.warning("Kodi websocket connection error: {}".format(error))
         return hndl
 
     def _on_ws_close(self):
-        def hndl(ws):
+        def hndl(*_):
             self._ws = None
             self.logger.warning("Kodi websocket connection closed")
             time.sleep(5)
@@ -600,7 +601,8 @@ class MediaKodiPlugin(MediaPlugin):
         try:
             kodi = self._get_kodi()
             players = kodi.Player.GetActivePlayers().get('result', [])
-        except:
+        except Exception as e:
+            self.logger.debug(f'Could not get active players: {str(e)}')
             return ret
 
         ret['state'] = PlayerState.STOP.value
